@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.759';
+our $VERSION = '1.761';
 
 use Exporter qw( import );
 
@@ -118,6 +118,15 @@ sub line_fold {
         $str =~ s/\x{feff}//g;
         $str =~ s/(\e\[[\d;]*m)/push( @color, $1 ) && "\x{feff}"/ge;
     }
+    if ( $opt->{binary_filter} && substr( $str, 0, 100 ) =~ /[\x00-\x08\x0B-\x0C\x0E-\x1F]/ ) {
+        #$str = $self->{binary_filter} == 2 ? sprintf("%v02X", $_[0]) =~ tr/./ /r : 'BNRY';  # perl 5.14
+        if ( $opt->{binary_filter} == 2 ) {
+            ( $str = sprintf( "%v02X", $_[0] ) ) =~ tr/./ /; # use unmodified string
+        }
+        else {
+            $str = 'BNRY';
+        }
+    }
     $str =~ s/\t/ /g;
     $str =~ s/[^\v\P{Cc}]//g; # remove control chars but keep vertical spaces
     $str =~ s/[\p{Noncharacter_Code_Point}\p{Cs}]//g;
